GdgTextTheme class
- Annotations
Constructors
- GdgTextTheme({required TextStyle h1, required TextStyle h2, required TextStyle h3, required TextStyle h4, required TextStyle h5, required TextStyle body1Medium, required TextStyle body2Medium, required TextStyle linkMedium, required TextStyle linkSmall, required TextStyle body1Small, required TextStyle body2Small, required TextStyle label1, required TextStyle label2, required TextStyle caption})
-
const
Properties
- body1Medium → TextStyle
-
final
- body1Small → TextStyle
-
final
- body2Medium → TextStyle
-
final
- body2Small → TextStyle
-
final
- caption → TextStyle
-
final
- h1 → TextStyle
-
final
- h2 → TextStyle
-
final
- h3 → TextStyle
-
final
- h4 → TextStyle
-
final
- h5 → TextStyle
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- label1 → TextStyle
-
final
- label2 → TextStyle
-
final
- linkMedium → TextStyle
-
final
- linkSmall → TextStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Properties
- defaultTextTheme → GdgTextTheme
-
no setter